@@ -2,7 +2,7 @@
 ** BoundingBox.cpp                                                      **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2019 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -76,7 +76,7 @@ vector<Length> BoundingBox::extractLengths (string boxstr) {
 	vector<string> lengthStrings = util::split(boxstr, " ");
 	for (const string &lenstr : lengthStrings) {
 		if (!lenstr.empty())
-			lengths.emplace_back(Length(lenstr));
+			lengths.emplace_back(lenstr);
 	}
 	return lengths;
 }
@@ -207,7 +207,7 @@ void BoundingBox::operator += (const BoundingBox &bbox) {
 
 
 static inline bool almost_equal (double v1, double v2) {
-	return fabs(v1-v2) < 1e-10;
+	return abs(v1-v2) < 1e-10;
 }
 
 
