@@ -2,7 +2,7 @@
 ** CLCommandLine.cpp                                                    **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2018 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -39,7 +39,7 @@ void CommandLine::parse (int argc, char **argv) {
 	for (int i=1; i < argc; i++) {
 		istringstream iss(argv[i]);
 		if (filesOnly || iss.peek() != '-')
-			_files.push_back(argv[i]);
+			_files.emplace_back(argv[i]);
 		else {
 			iss.get();  // skip dash
 			if (iss.peek() < 0)
