@@ -1,8 +1,8 @@
 /*************************************************************************
 ** GFTracer.cpp                                                         **
 **                                                                      **
-** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
+** This file is part of dvisvgm -- a fast DVI to SVG converter          **
+** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -18,45 +18,29 @@
 ** along with this program; if not, see <http://www.gnu.org/licenses/>. **
 *************************************************************************/
 
-#include <config.h>
-#include <iostream>
 #include <fstream>
-#include <sstream>
-#include "GFTracer.h"
-#include "Glyph.h"
-#include "Message.h"
-
-#ifdef __MSVC__
 #include <potracelib.h>
-#else
-extern "C" {
-#include <potracelib.h>
-}
-#endif
+#include "GFTracer.hpp"
+#include "Glyph.hpp"
+#include "Message.hpp"
 
 using namespace std;
 
 
-GFTracer::GFTracer (istream &is)
-	: GFReader(is), _unitsPerPoint(0.0)
-{
-}
-
-
 /** Constructs a new GFTracer.
  *  @param[in] is GF file is read from this stream
- *  @param[in] upp target units per TeX point */
+ *  @param[in] upp target units per PS point */
 GFTracer::GFTracer (istream &is, double upp)
 	: GFReader(is), _unitsPerPoint(upp)
 {
 }
 
 
-void GFTracer::beginChar (UInt32 c) {
+void GFTracer::beginChar (uint32_t c) {
 }
 
 
-void GFTracer::endChar (UInt32 c) {
+void GFTracer::endChar (uint32_t c) {
 	const Bitmap &bitmap = getBitmap();
 	if (bitmap.empty())
 		return;
