@@ -2,7 +2,7 @@
 ** MetafontWrapper.cpp                                                  **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2019 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -79,18 +79,8 @@ bool MetafontWrapper::call (const string &mode, double mag) {
 	string mf_messages;
 	mf_process.run(_dir, &mf_messages);
 
-	// get resolution value from stdout created by above MF command
-	char buf[256];
-	istringstream iss(mf_messages);
-	int resolution = 0;
-	while (iss) {
-		iss.getline(buf, sizeof(buf));
-		string line = buf;
-		if (line.substr(0, 3) == ">> ") {
-			resolution = stoi(line.substr(3));
-			break;
-		}
-	}
+	int resolution = getResolution(mf_messages);
+
 	// compose expected name of GF file (see Metafont Book, p. 324)
 	string gfname = _dir + _fontname + ".";
 	if (resolution > 0)
@@ -101,6 +91,52 @@ bool MetafontWrapper::call (const string &mode, double mag) {
 }
 
 
+/** Returns the resolution applied to a GF file generated by Metafont. Since the resolution
+ *  is part of the filename suffix, we need this value in order to address the file.
+ *  @param[in] mfMessage output written to stdout by Metafont
+ *  @return the resolution (>0 on success, 0 otherwise) */
+int MetafontWrapper::getResolution (const string &mfMessage) const {
+	int res = 0;
+	char buf[256];
+	if (!mfMessage.empty()) {
+		// try get resolution value written to stdout by above MF command
+		istringstream iss(mfMessage);
+		while (iss) {
+			iss.getline(buf, sizeof(buf));
+			string line = buf;
+			if (line.substr(0, 3) == ">> ") {
+				res = stoi(line.substr(3));
+				break;
+			}
+		}
+	}
+	// couldn't read resolution from stdout, try to get it from log file
+	if (res == 0) {
+		ifstream ifs(_dir+_fontname+".log");
+		while (ifs) {
+			ifs.getline(buf, sizeof(buf));
+			string line = buf;
+			if (line.substr(0, 18) == "Output written on ") {
+				line = line.substr(18);
+				size_t pos = line.find(' ');
+				line = line.substr(0, pos);
+				pos = line.rfind('.');
+				if (pos != string::npos && line.substr(line.length()-2) == "gf") {
+					line.pop_back();
+					line.pop_back();
+					try {
+						res = stoi(line.substr(pos+1));
+					}
+					catch (...) {
+					}
+				}
+			}
+		}
+	}
+	return res;
+}
+
+
 /** Calls Metafont if output files (tfm and gf) don't already exist.
  *  @param[in] mode Metafont mode to be used (e.g. 'ljfour')
  *  @param[in] mag magnification factor
