@@ -1,8 +1,8 @@
 /*************************************************************************
 ** PageSize.cpp                                                         **
 **                                                                      **
-** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
+** This file is part of dvisvgm -- a fast DVI to SVG converter          **
+** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -18,56 +18,49 @@
 ** along with this program; if not, see <http://www.gnu.org/licenses/>. **
 *************************************************************************/
 
-#include <config.h>
 #include <algorithm>
 #include <cctype>
 #include <cmath>
 #include <sstream>
-#include "PageSize.h"
+#include "PageSize.hpp"
+#include "utility.hpp"
 
 using namespace std;
 
-// make sure tolower is a function (and not a macro)
-// so that 'transform' can be applied
-static int my_tolower (int c) {
-	return tolower(c);
-}
 
-
-/** Computes width and height of ISO/DIN An in millimeters.
+/** Computes width and height of ISO/DIN An.
  *  @param[in]  n the A level (e.g. n=4 => DIN A4)
  *  @param[out] width contains the page width when function returns
  *  @param[out] height contains the page height when function returns */
-static void computeASize (int n, double &width, double &height) {
-	double sqrt2 = sqrt(2.0);
-	height = floor(1189.0/pow(sqrt2, n)+0.5);
-	width  = floor(height/sqrt2+0.5);
+static void computeASize (int n, Length &width, Length &height) {
+	height.set(round(1189.0/pow(math::SQRT2, n)), Length::Unit::MM);
+	width.set(round(height.mm()/math::SQRT2), Length::Unit::MM);
 }
 
 
-/** Computes width and height of ISO/DIN Bn in millimeters.
+/** Computes width and height of ISO/DIN Bn.
  *  @param[in]  n the B level (e.g. n=4 => DIN B4)
  *  @param[out] width contains the page width when function returns
  *  @param[out] height contains the page height when function returns */
-static void computeBSize (int n, double &width, double &height) {
-	double w, h;
+static void computeBSize (int n, Length &width, Length &height) {
+	Length w, h;
 	computeASize(n, width, height);
 	computeASize(n-1, w, h);
-	width = floor(sqrt(width * w)+0.5);
-	height = floor(sqrt(height * h)+0.5);
+	width.set(round(sqrt(width.mm() * w.mm())), Length::Unit::MM);
+	height.set(round(sqrt(height.mm() * h.mm())), Length::Unit::MM);
 }
 
 
-/** Computes width and height of ISO/DIN Cn in millimeters.
+/** Computes width and height of ISO/DIN Cn.
  *  @param[in] n the C level (e.g. n=4 => DIN C4)
  *  @param[out] width contains the page width when function returns
  *  @param[out] height contains the page height when function returns */
-static void computeCSize (int n, double &width, double &height) {
-	double w, h;
+static void computeCSize (int n, Length &width, Length &height) {
+	Length w, h;
 	computeASize(n, width, height);
 	computeBSize(n, w, h);
-	width = floor(sqrt(width * w)+0.5);
-	height = floor(sqrt(height * h)+0.5);
+	width.set(round(sqrt(width.mm() * w.mm())), Length::Unit::MM);
+	height.set(round(sqrt(height.mm() * h.mm())), Length::Unit::MM);
 }
 
 
@@ -75,34 +68,35 @@ static void computeCSize (int n, double &width, double &height) {
  *  @param[in] n the D level (e.g. n=4 => DIN D4)
  *  @param[out] width contains the page width when function returns
  *  @param[out] height contains the page height when function returns */
-static void computeDSize (int n, double &width, double &height) {
-	double w, h;
+static void computeDSize (int n, Length &width, Length &height) {
+	Length w, h;
 	computeASize(n, width, height);
 	computeBSize(n+1, w, h);
-	width = floor(sqrt(width * w)+0.5);
-	height = floor(sqrt(height * h)+0.5);
+	width.set(round(sqrt(width.mm() * w.mm())), Length::Unit::MM);
+	height.set(round(sqrt(height.mm() * h.mm())), Length::Unit::MM);
 }
 
 
 /** Constructs a PageSize object of given size.
  *  @param[in] name specifies the page size, e.g. "A4" or "letter" */
-PageSize::PageSize (string name) : _width(0), _height(0) {
+PageSize::PageSize (const string &name) : _width(0), _height(0) {
 	resize(name);
 }
 
 
-void PageSize::resize (double w, double h) {
+void PageSize::resize (Length w, Length h) {
 	_width = w;
 	_height = h;
 }
 
+
 void PageSize::resize (string name) {
 	if (name.length() < 2)
 		throw PageSizeException("unknown page format: "+name);
 
-	transform(name.begin(), name.end(), name.begin(), my_tolower);
+	name = util::tolower(name);
 	// extract optional suffix
-	size_t pos = name.rfind("-");
+	size_t pos = name.rfind('-');
 	bool landscape = false;
 	if (pos != string::npos) {
 		string suffix = name.substr(pos);
@@ -114,24 +108,24 @@ void PageSize::resize (string name) {
 	}
 
 	if (name == "invoice") {
-		_width = 140;
-		_height = 216;
+		_width = 140_mm;
+		_height = 216_mm;
 	}
 	else if (name == "executive") {
-		_width = 184;
-		_height = 267;
+		_width = 184_mm;
+		_height = 267_mm;
 	}
 	else if (name == "legal") {
-		_width = 216;
-		_height = 356;
+		_width = 216_mm;
+		_height = 356_mm;
 	}
 	else if (name == "letter") {
-		_width = 216;
-		_height = 279;
+		_width = 216_mm;
+		_height = 279_mm;
 	}
 	else if (name == "ledger") {
-		_width = 279;
-		_height = 432;
+		_width = 279_mm;
+		_height = 432_mm;
 	}
 	else if (isdigit(name[1]) && name.length() < 5) {  // limit length of number to prevent arithmetic errors
 		istringstream iss(name.substr(1));
@@ -145,13 +139,8 @@ void PageSize::resize (string name) {
 			default  : throw PageSizeException("invalid page format: "+name);
 		}
 	}
-	if (_width == 0 || _height == 0)
+	if (_width.pt() == 0 || _height.pt() == 0)
 		throw PageSizeException("unknown page format: "+name);
 	if (landscape)
 		swap(_width, _height);
-
-	const double ptpmm = 72.27/25.4; // TeX points per millimeter (72.27pt = 1in = 25.4mm)
-	_width *= ptpmm;
-	_height *= ptpmm;
 }
-
