@@ -2,7 +2,7 @@
 ** UtilityTest.cpp                                                      **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2019 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -91,14 +91,14 @@ TEST(UtilityTest, split) {
 	parts = split("1,2 , 3, 4 ,,5", ",");
 	ASSERT_EQ(parts.size(), 6u);
 	size_t count=0;
-	for (const string &part : {"1", "2 ", " 3", " 4 ", "", "5"}) {
+	for (string part : {"1", "2 ", " 3", " 4 ", "", "5"}) {
 		EXPECT_EQ(parts[count++], part);
 	}
 
 	parts = split("1 sep2sep3, sep", "sep");
 	ASSERT_EQ(parts.size(), 4u);
 	count=0;
-	for (const string &part : {"1 ", "2", "3, ", ""}) {
+	for (string part : {"1 ", "2", "3, ", ""}) {
 		EXPECT_EQ(parts[count++], part);
 	}
 }
